#[repr(u8)]pub enum Redmul {
FULLSZ = 0,
_RESERVED_1 = 1,
VALUE_64BIT = 2,
_RESERVED_3 = 3,
}Variants
FULLSZ = 0
full size mode, 3 least significant bits of pointer and length are ignored, minimum supported length 0x0008
_RESERVED_1 = 1
VALUE_64BIT = 2
64-bit mode, 3 least significant bits of pointer and length are ignored, minimum supported length 0x0008
_RESERVED_3 = 3
Implementations